#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXuXuXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXuXiXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXuXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXuXyXuXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXuXuXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX_ ^ ) ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ^ Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ~ Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q W ! R I U U U U U U U U U U U U U U U Y / ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ) ! I U U U U U U U U U U U U U U U U W ` uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX^ U J K J J J J J J J J J J J J J K H R  .| | | | | | | | | | | | | | | ..) [  .| | | | | | | | | | | | | | .._ -.w.8.9.9.9.9.9.9.9.9.9.9.9.9.9.0.5.U J K J J J J J J J J J J J J K K G ] w.8.9.9.9.9.9.9.9.9.9.9.9.9.9.8.w.] W uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX) J x v c c c c c c c c c c c c c v l W h.d.d.d.d.d.d.d.d.d.d.d.d.d.d.s.k.-.w.h.d.d.d.d.d.d.d.d.d.d.d.d.d.d.l.:.].vXaXdXdXdXdXdXdXdXdXdXdXdXdXsXhX9XF z v c c c c c c c c c c c c c n s 7.bXpXsXsXsXsXsXsXsXsXsXsXsXsXdXpXbXw.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( K v n b b b b b b b b b b b b b n x W a.u.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.&.7.p.u.u.u.u.u.u.u.u.u.u.u.u.u.y.d.=.!.iX7X9X9X9X9X9X9X9X9X9X9X9X9X8XwX:XG c n b b b b b b b b b b b b b m g 3.pX6X0XwXwXwXwXwXwXwXwXwXwXqX9X6XpX8.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sX0X3X%X*X*X*X*X*X*X*X*X&X-XqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX&X;X6X3X4X4X4X4X4X4X2XwXzX6XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX=X5XtXeXeXeXeXeXeXeXqXsXvX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X3XeXqXqXqXqXqXqXwX9XpXcX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXwX*X1XqX9X9X9X9X9X9X9X7XuXcX5XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.sXqX-XwXdXpXaXaXaXaXaXaXiXlXbX5XfX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XrX,XG x n b b b b b b b b b b b b b m g 4.dX9XqXlXcXcXcXcXcXcXcXcXxXvXaX7XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX( K b m n n n n n n n n n n n n n m c W p.y.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.&.8.s.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.Q.iX7X9X9X9X9X9X9X9X9X9X9X9X9X8XwX:XG c n b b b b b b b b b b b b b m g 3.aX7X0X7X6X6X6X6X6X6X6X6X6X6X8X8XaX8.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( G g k j j j j j j j j j j j j j k d R j.d.f.f.f.f.f.f.f.f.f.f.f.f.f.d.k.-.7.p.u.u.u.u.u.u.u.u.u.u.u.u.u.y.d.*.].vXaXdXdXdXdXdXdXdXdXdXdXdXdXsXhX9XF z b v v v v v v v v v v v v v n d 5.kXrXyXuXuXuXuXuXuXuXuXuXuXuXuXrXkX0.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX^ ! [ ] ] ] ] ] ] ] ] ] ] ] ] ] ] ] [ / [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ [ { ( ;.2.<.<.<.<.<.<.<.<.<.<.<.<.<.<.3.@.%.7.3.4.4.4.4.4.4.4.4.4.4.4.4.4.5.1.U G H H H H H H H H H H H H H H J S ..c.h.j.j.j.j.j.j.j.j.j.j.j.j.j.h.c.X.W iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 0.jXwXtXrXrXrXrXrXrXrXrXrXrXrXtXwXjX4.a c z z z z z z z z z z z z z x j D >XeX9X0X0X0X0X0X0X0X0X0X0X0X0X8XiX_.g g g f f f f f f f f f f f f g d z G v m n n n n n n n n n n n n n M h 2.tX2X4X4X4X4X4X4X4X4X4X4X4X4X4X2XtX7.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sX8XqXeXeXeXeXeXeXeXeXeXeXeXqX8XsX4.h M n n n n n n n n n n n n n n c G ,XtXqXqXqXqXqXqXqXqXqXqXqXqXqX0XaX`.v M m B V B B B B B B B B V N m n C F c b m M M M M M M M M M M m b m f 4.gX0XeXeXeXeXeXeXeXeXeXeXeXeXeX0XgX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sX9X6X:X>X>X>X>X>X>X>X>X>X,X0X9XdX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n n d i i i i i i i i i u g n v B F c n h u i i i i i i i i i s b m g 4.dX8XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX%X%X,X>X>X>X>X>X>X>X;X6XhX6XdX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n v 3 i i i i i i i i p r C C x B F x M 6 t p i i i i i i p t b D b g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X6XyXrXrXrXrXrXrXrXwXfXvX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 0 B M M M M M M M N b R Z x B F c m 0 n N M M M M M M N b P J v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X3XwX0X0X0X0X0X0XqX8XpXxX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 n v v v v v v v b z U Z x B F x m 9 x b v v v v v v b z H H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 m b b b b b b b n x U Z x B F x m 9 x n b b b b b b n x J H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 m b b b b b b b n x U Z x B F x m 9 x n b b b b b b n x J H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 m b b b b b b b n x U Z x B F x m 9 x n b b b b b b n x J H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 m b b b b b b b n x U Z x B F x m 9 x n b b b b b b n x J H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 m b b b b b b b n x U Z x B F x m 9 x n b b b b b b n x J H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 m b b b b b b b n x U Z x B F x m 9 x n b b b b b b n x J H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X3XwX0X0X0X0X0X0XqX8XpXxX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 n v v v v v v v b z U Z x B F x m 9 x b v v v v v v b z H H v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X6XyXeXrXrXrXrXrXrXqXfXvX5XfX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n c 9 N m M M M M M M M v R Z x B F c m 9 b M M M M M M M M v P J v g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9X9XcXmXnXnXnXnXnXnXnXnXNXgX6XdX4.g m b b b b b b b b b b b b b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XpX_.c n v N W R R R R R R R R R Q M c B F c b b R R R R R R R R R R ! Z b g 4.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX9XdX9.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 8.pX6X9X7X7X7X7X7X7X7X7X7X7X6X7X6XpX3.h M n n n n n n n n n n n n n n c G :XwX8X8X8X8X8X8X8X8X8X8X8X8X8X7XyX).c n n n c v v v v v v v c v c b v B F v n n v v v v v v v v v v c b M g 3.pX6X8X8X8X8X8X8X8X8X8X8X8X8X8X6XpX8.U pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXI w.nXaXdXdXfXfXfXfXfXfXfXfXfXfXdXpXnX7.a b x x x x x x x x x x x x x c l F 0XjXdXfXfXfXfXfXfXfXfXfXfXfXfXsXcX.Xl v c c c c c c c c c c c c v c x M D l c x c c c c c c c c c c c c b a 7.nXaXfXfXfXfXfXfXfXfXfXfXfXfXfXaXnXw.I pXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXiXW +.A.m.N.N.N.N.N.N.N.N.N.N.N.N.N.m.A.O.Z H G G G G G G G G G G G G G G F I x.B.M.M.M.M.M.M.M.M.M.M.M.M.M.m.C.u.D F F F F F F F F F F F F F F F F H I F G G G G G G G G G G G G G G H Z o.Z.m.M.M.M.M.M.M.M.M.M.M.M.M.M.m.A.+.W iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXT <.=X.XoXoXoXoXoXoXoXoXoXoXoXoXoXXX#Xu.=X<X,X,X,X,X,X,X,X,X,X,X,X,X,X:X0Xx.u h g g g g g g g g g g g g g g d m G M B N N N N N N N N N N N B B C z x.0X:X,X,X,X,X,X,X,X,X,X,X,X,X,X>X3X) u h g g g g g g g g g g g g g h d G ) yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU q.zXtXuXuXuXuXuXuXuXuXuXuXuXuXuXyXfXl.7XyXrXrXrXrXrXrXrXrXrXrXrXrXrXwXjXB.h N m N N N N N N N N N N N M m b S Z x v b n n n n n n n n n n b v n f B.jXwXrXrXrXrXrXrXrXrXrXrXrXrXrXrXiX[ l M m m m m m m m m m m m m m m n K ( uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sX8X0X0X0X0X0X0X0X0X0X0X0X0X0X9XtXj.4XwX0X0X0X0X0X0X0X0X0X0X0X0X0X8XdXM.g m b k h h h h h h h h h h z n c A A c n l h h h h h h h h h h k b m g M.dX8X0X0X0X0X0X0X0X0X0X0X0X0X0X0XrX] k m b b b b b b b b b b b b b n v K ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N k 2 r w w w w w w w e 0 V M c A A c b 3 w w w w w w w w e 9 b V n g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h r C M M M M M M M N m ! m c A A v c 0 B M M M M M M M N b E Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M c v v v v v v b c R m c A A v c 9 n v v v v v v v b z U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M v b b b b b b b c E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M v b b b b b b b c E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M v b b b b b b b c E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M v b b b b b b b c E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M v b b b b b b b c E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h w M v b b b b b b b c E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h e N b b b b b b b n v E m c A A v c 9 m b b b b b b b n x U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g N h 0 m c c c c c c c v x E m c A A v c 7 b c c c c c c c v l U Z b g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXqXqXqXqXqXqXqXqXqXqXqXqX0XyXj.4XeXqXqXqXqXqXqXqXqXqXqXqXqXqX8XfXM.g M z V ! R E E E E E E E E ! b c A A v c b Q R E E E E E E E R / B n g M.fX8XqXqXqXqXqXqXqXqXqXqXqXqXqX0XtX] j n b b b b b b b b b b b b b b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 8.aX7X9X9X9X9X9X9X9X9X9X9X9X9X9X8XrXh.3XqX9X9X9X9X9X9X9X9X9X9X9X9X9X7XsXm.g m n M m m m m m m m m m m b n c A A c n m m m m m m m m m m m n b m g m.sX7X9X9X9X9X9X9X9X9X9X9X9X9X9X8XeX] k m b b b b b b b b b b b b b n v K ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXI q.xXuXpXpXpXpXpXpXpXpXpXpXpXpXpXiXgXx.eXdXaXaXaXaXaXaXaXaXaXaXaXaXaXuXbXZ.f n v v v v v v v v v v v v v b x Z A v n b b b b b b b b b b b b n M g Z.bXuXaXaXaXaXaXaXaXaXaXaXaXaXaXpXgX[ h n v v v v v v v v v v v v v b c J ( yXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXiXR :. X)._._._._._._._._._._._._._._.[.9.R.^.~.~.~.~.~.~.~.~.~.~.~.~.~.Q.].t.c B N M M M M M M M M M M M M N m D C z c c c c c c c c c c c c c c v h t.].Q.~.~.~.~.~.~.~.~.~.~.~.~.~.~.(.) v N M M M M M M M M M M M M M N m L ( uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J z c c c c c c c c c c c c c c c l Y ;.=.=.=.=.=.=.=.=.=.=.=.=.=.=.=.;.| ,.7.5.5.5.5.5.5.5.5.5.5.5.5.5.5.9.+.M.|.)._._._._._._._._._._._._._.[.Y.| ;.=.=.=.=.=.=.=.=.=.=.=.=.=.=.-.&. .7.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.9.] ! uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( K v n n n n n n n n n n n n n n n x Q j.f.f.f.f.f.f.f.f.f.f.f.f.f.f.d.l.;.0.f.a.s.s.s.s.s.s.s.s.s.s.s.s.a.j.;.`.zXuXpXpXpXpXpXpXpXpXpXpXpXpXiXgX,X;.l.d.f.f.f.f.f.f.f.f.f.f.f.f.f.g.s.$.f.a.s.s.s.s.s.s.s.s.s.s.s.s.s.a.h. .Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( K v n b b b b b b b b b b b b b n x W a.u.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.&.8.a.u.u.u.u.u.u.u.u.u.u.u.u.u.u.f.=.!.iX7X9X9X9X9X9X9X9X9X9X9X9X9X8XrX%X*.s.y.u.u.u.u.u.u.u.u.u.u.u.u.u.i.t.@.p.u.u.u.u.u.u.u.u.u.u.u.u.u.u.y.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b n z W a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.aX9XqXqXqXqXqXqXqXqXqXqXqXqX0XyX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( K v n b b b b b b b b b b b b b n x W a.u.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.8.a.u.i.i.i.i.i.i.i.i.i.i.i.i.u.f.=.~.pX8X0X0X0X0X0X0X0X0X0X0X0X0X9XtX&X*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.i.t.#.a.u.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J x v v v v v v v v v v v v v v b l E d.i.p.p.p.p.p.p.p.p.p.p.p.p.p.i.f.*.w.h.d.d.d.d.d.d.d.d.d.d.d.d.d.s.l.:.(.hXrXyXyXyXyXyXyXyXyXyXyXyXyXtXsX;X=.h.a.a.a.a.a.a.a.a.a.a.a.a.a.a.s.i.$.d.a.a.a.a.a.a.a.a.a.a.a.a.a.a.p.h. .Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX( L M B B B B B B B B B B B B B B B m Q u.r.t.t.t.t.t.t.t.t.t.t.t.t.t.r.p.%.*.3.1.1.1.1.1.1.1.1.1.1.1.1.1.1.5...K.<X%X&X&X&X&X&X&X&X&X&X&X&X&X&X;X].@.q.8.8.8.8.8.8.8.8.8.8.8.8.8.8.9.6.X.0.8.8.8.8.8.8.8.8.8.8.8.8.8.8.7.w.[ Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX/ I D F F F F F F F F F F F F F F F F I G F F F F F F F F F F F F F F G D I x.B.M.M.M.M.M.M.M.M.M.M.M.M.M.m.Z.t.| ;.*.*.*.*.*.*.*.*.*.*.*.*.*.*.=.@.} -.&.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.[ =.*.*.*.*.*.*.*.*.*.*.*.*.*.*.&.-.) ~ uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J z c c c c c c c c c c c c c c c x G v x c x x x x x x x x x x x c c l F 9XjXsXdXdXdXdXdXdXdXdXdXdXdXdXaXvX].;.l.s.d.d.d.d.d.d.d.d.d.d.d.d.d.h.q.-.k.s.d.d.d.d.d.d.d.d.d.d.d.d.d.f.p.%.g.d.d.d.d.d.d.d.d.d.d.d.d.d.d.s.k...Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( K v n b b b b b b b b b b b b b n b H m b m M m M M M M M M M M m b n c G :XwX8X8X8X8X8X8X8X8X8X8X8X8X8X7XiXQ.=.d.y.u.u.u.u.u.u.u.u.u.u.u.u.u.a.8.&.s.y.u.u.u.u.u.u.u.u.u.u.u.u.u.i.t.@.p.u.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n m h 6 0 9 9 9 9 9 9 9 9 9 b n x G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M u t n x x x x x x x x b R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i p N b n n n n n n b M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i i M v b b b b b b v M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i i M v b b b b b b v M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i i M v b b b b b b v M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i i M v b b b b b b v M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i i M v b b b b b b v M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i i M v b b b b b b v M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i p N b n n n n n n b M R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n M i t b z x x x x x x z v R v c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( J c b b b b b b b b b b b b b b b v H n m s b P H J J J J J J H P ! c c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX( K c b b b b b b b b b b b b b b b v H n b b D J H H H H H H H H J Z b c G ,XrX0XqXqXqXqXqXqXqXqXqXqXqXqX9XaX~.=.f.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.u.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX( K n m m m m m m m m m m m m m m m n J m n n c x c c c c c c c c x v m c G >XrX0X0X0X0X0X0X0X0X0X0X0X0X0X8XpX~.-.g.i.p.p.p.p.p.p.p.p.p.p.p.p.i.s.9.*.f.i.p.p.p.p.p.p.p.p.p.p.p.p.p.p.y.#.s.i.p.p.p.p.p.p.p.p.p.p.p.p.p.i.f. .Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXyX) G s g g g g g g g g g g g g g g g d D c z z x x x x x x x x x x x x x j D 3XiXrXtXtXtXtXtXtXtXtXtXtXtXtXeXgX(.&.s.t.t.t.t.t.t.t.t.t.t.t.t.t.t.i.6.&.p.t.t.t.t.t.t.t.t.t.t.t.t.t.t.y.e.@.u.t.t.t.t.t.t.t.t.t.t.t.t.t.t.t.a.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX! ] 7.3.4.4.4.4.4.4.4.4.4.4.4.4.4.3.6.{ ' { [ [ [ [ [ [ [ [ [ [ [ [ [ [ { ( ` [ ] ] ] ] ] ] ] ] ] ] ] ] ] ] [ )  .$.@.#.#.#.#.#.#.#.#.#.#.#.#.#.$.X.[ %.@.#.#.#.#.#.#.#.#.#.#.#.#.#.#.@.' $.#.#.#.#.#.#.#.#.#.#.#.#.#.#.@.%.( ~ uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXI w.bXpXsXsXsXsXsXsXsXsXsXsXsXsXdXaXcXi.r.h.f.f.f.f.f.f.f.f.f.f.f.f.f.d.k.-.h k j j j j j j j j j j j j j k h v 7.f.p.a.a.a.a.a.a.a.a.a.a.a.a.a.d.0.=.g.p.a.a.a.a.a.a.a.a.a.a.a.a.a.s.u.$.d.p.a.a.a.a.a.a.a.a.a.a.a.a.a.p.g. .Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 8.pX6X0XwXwXwXwXwXwXwXwXwXwXqX9X7XuXe.9.p.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.&.b m m B B B B B B B B B B B M m n N 5.a.u.i.i.i.i.i.i.i.i.i.i.i.i.u.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.u.i.t.#.p.u.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sX0X3X&X=X*X*X*X*X*X*X*X*X-XqX9XpXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c n c e e e e e e e e e e q k m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX%X;X5X3X3X3X3X3X3X3X1XwXlX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h 6 k f g g g g g g g d P M v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X6XtXeXeXeXeXeXeXeXqXdXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h r V n m m m m m m M n W m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X3XeXqXqXqXqXqXqXqX9XpXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w M v b b b b b b b c R m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w M v b b b b b b b c E m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w M v b b b b b b b c E m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w M v b b b b b b b c E m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w M v b b b b b b b c E m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXqX9XaXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w M v b b b b b b b c E m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX*X4XeXqXqXqXqXqXqXwX9XaXcX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h w N v b b b b b b n v E m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXwX&X2XqX9X9X9X9X9X9X9X7XiXxX6XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h 0 n x c c c c c c c z R m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.sXqX-XwXsXpXpXpXpXpXpXpXuXlXvX5XaXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c m h i F C Z Z Z Z Z Z Z C ~ m v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 9.dX9XqXzXvXcXcXcXcXcXcXcXcXbXaX7XpXr.0.a.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.*.c n c S T U U U U U U U U Y L b v M 5.s.u.i.i.i.i.i.i.i.i.i.i.i.i.i.a.8.*.d.u.i.i.i.i.i.i.i.i.i.i.i.i.i.p.t.#.a.i.i.i.i.i.i.i.i.i.i.i.i.i.i.u.d.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU 8.pX6X9X6X5X5X5X5X5X5X5X5X5X5X7X7XuXe.9.p.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.&.v n n v x x x x x x x x x x x n b N 5.a.y.u.u.u.u.u.u.u.u.u.u.u.u.u.p.7.&.s.y.u.u.u.u.u.u.u.u.u.u.u.u.u.i.t.@.p.u.u.u.u.u.u.u.u.u.u.u.u.u.u.y.s.| Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXpXU w.bXpXdXdXfXfXfXfXfXfXfXfXdXfXdXaXcXi.r.g.d.d.d.d.d.d.d.d.d.d.d.d.d.s.k.-.z v v v v v v v v v v v v v v v c m 9.h.d.d.d.d.d.d.d.d.d.d.d.d.d.d.h.w.-.k.s.d.d.d.d.d.d.d.d.d.d.d.d.d.f.a.%.g.d.d.d.d.d.d.d.d.d.d.d.d.d.d.s.k...Q iXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuXW ] w.8.9.9.9.9.9.9.9.9.9.9.9.9.9.8.q.} {  .| | | | | | | | | | | | | | ..) J K K J J J J J J J J J J J J K J L ]  .| | | | | | | | | | | | | |  .[ ) ..| | | | | | | | | | | | | |  .| (  .| | | | | | | | | | | | | | | ..~ ! uXcXkXlXlXlXlXlX",
"lXlXlXlXlXkXcXuX` W U U U U U U U U U U U U U U U U I Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ~ ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ( ! Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ~ Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ~ Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! ` uXcXkXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXuXuXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXpXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXuXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXyXuXuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXuXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXiXuXuXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXlXlXlXlX",
"lXlXkXbXCXVXVXVXVXVXVXVXVXVXVXVXVXVXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXVXVXVXVXVXVXVXVXVXVXVXVXVXCXCXCXCXCXCXCXCXCXCXCXCXCXCXCXVXlXlXlXlX",
"lXkXbX2XI.Q.W.W.W.W.W.W.W.W.W.W.W.W.W.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.Y.U.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.U.Y.E.W.W.W.W.W.W.W.W.W.W.W.W.W.R.U.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.^.jXzXlXlX",
"lXhXCXI.b G S S S S S S S S S S S S D L P P P P P P P P P P P P P K P P P P P P P P P P P P P L W ! ! ! ! ! ! ! ! ! ! Q ! W D S S S S S S S S S S S D A K ~ Q ! ! ! ! ! ! ! ! ! Q ~ P W dXxXlXlX",
"lXhXVXQ.G V M M M M M M M M M M M M N 6.f.p.a.a.a.a.a.a.a.a.a.a.i.:.s.p.a.a.a.a.a.a.a.a.a.p.d.5.,XrXqXqXqXqXqXqXqXqXqX0XtX:XG n N M M M M M M M M M B k 1.sX9XqXwXwXwXwXwXwXwXwX9XdXK./ hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.i.i.i.i.i.i.i.i.i.i.p.u.-.a.i.i.i.i.i.i.i.i.i.i.i.a.3.<XtXqXwXwXwXwXwXwXwXwXqXyX:XA c b b b b b b b b b b m f ,.dX0XqX0X0X0X0X0X0X0X0X9XfXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 3.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.u.a.2.,XrX0XqXqXqXqXqXqXqXqX0XrX;XS c n b b b b b b b b b m f ,.dX5X#X-X=X=X=X=X=X*X,XrXaXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.fX2X:XtXwXwXwXwXwX0XaXhXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.dX3X:XeX0XqXqXqXqX9XiXfXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.dX3X:XeX0XqXqXqXqX9XpXgXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.dX3X:XeX0XqXqXqXqX9XpXgXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.dX3X:XeX0XqXqXqXqX9XpXgXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.dX3X:XrXqXqXqXqXqX9XpXgXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.dX3X:XeX0X0X0X0XqX9XiXfXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XtX;XS c n b b b b b b b b b m f ,.fX2X>XyXeXeXeXeXrXqXsXhXpXJ.! hXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 3.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.u.i.i.i.i.i.i.i.i.i.u.p.2.>XeX9X0X0X0X0X0X0X0X0X9XeX-XS c n b b b b b b b b b m g ,.aX5XiXxXlXlXlXlXlXlXcXuXpXH.! hXxXlXlX",
"lXhXVXW.D N n n n n n n n n n n n n m 5.f.p.a.a.a.a.a.a.a.a.a.a.i.:.g.d.d.d.d.d.d.d.d.d.d.d.g.5.4XaXyXyXyXyXyXyXyXyXyXtXaX1XA z v v v v v v v v v v n s 1.zXuXiXuXuXuXuXuXuXuXyXtXxXI.Q hXxXlXlX",
"lXhXVXW.S v z z z z z z z z z z z l c >.e.0.q.q.q.q.q.q.q.q.q.q.0.+.1.<.1.1.1.1.1.1.1.1.1.<.1.&.}.%X#X#X#X#X#X#X#X#X#X@X&X].G N V V V V V V V V V V C c %.+X].{.{.{.{.{.{.{.{.{.[.+Xl.^ hXxXlXlX",
"lXhXCXT.R ).)./.(.(.(.(.(.(.(.(./.'.J.A B V V V V V V V V V V Z v ;.[.~.^.^.^.^.^.^.^.^.^.!.[.i.c V N M M M M M M M M N M Z H C Z C C C C C C C C Z A n #.`.Q.!.!.!.!.!.!.!.!.!.Q.'.s./ gXxXlXlX",
"lXhXCXU.! pXaXsXdXdXdXdXdXdXdXdXiXhX;XM c v v v v v v v v v v n s w.cXuXaXaXaXaXaXaXaXaXaXuXcXF.d n n m m m m m m m m v c N Z z b n n n n n n n n b b s 1.xXiXaXaXaXaXaXaXaXaXaXiXcXU.Q hXxXlXlX",
"lXhXCXY.Q 9X0X-X*X=X=X=X=X=X=X=X7XtX+XN v n b b b b b b b b b M f 9.aX7X9X9X9X9X9X9X9X9X9X7XaXV.g M p t u y y y y y y c b B A b j r u y y y y u t h N f ,.pX7X9X9X9X9X9X9X9X9X9X7XaXH.! hXxXlXlX",
"lXhXCXY.! qXqX%X7X6X6X6X6X6X6X8XkXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m q l l l l l l k l L c B Z n y a z k l l l l h F Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X-XeXwXwXwXwXwXwXtXzXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m t m n n n n n n m I c B Z n i k M n n n n m v L Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m r b b b b b b b n I c B Z n u j m b b b b b x K Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m r b b b b b b b n I c B Z n u j m b b b b n x K Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m r b b b b b b b n I c B Z n u j m b b b b n x K Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m r b b b b b b b n I c B Z n u j m b b b b n x K Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X=XeXqXwXwXwXwXqXrXlXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m r n b n n n n b m I c B Z n i k m b n n n n c K Z d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X&X0X8X9X9X9X9X8XqXlXtX#XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g m w c x c c c c x v I c B Z n y f v x c c c c l J A d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wX0X9XxXlXlXlXlXlXlXcXzXrX$XN v b b b b b b b b b b m f 9.dX8XqXqXqXqXqXqXqXqXqX8XdXC.g n z I L L L L L L I Y x B Z b j F P L L L L L K E V d ,.sX9XqXqXqXqXqXqXqXqXqX9XdXJ.! hXxXlXlX",
"lXhXCXY.! wXeXtXuXuXuXuXuXuXuXuXwXuX$XV n M m m m m m m m m m B h 9.sX7X0X0X0X0X0X0X0X0X0X7XsXC.f m M B N N N N N N B m c B S n N C C C C C C C C B N j ,.pX7X0X0X0X0X0X0X0X0X0X7XaXH.! hXxXlXlX",
"lXhXCXY.Q 7X7X5X5X5X5X5X5X5X5X5X5XwXOXx s f f f f f f f f f f h q 9.xXtXiXiXiXiXiXiXiXiXiXtXzXD.g M b b b b b b b b b n b V m a f s s s s s s s s d h w >.zXtXiXiXiXiXiXiXiXiXiXtXzXI.Q hXxXlXlX",
"lXhXCXT.Y S.S.A.A.A.A.A.A.A.A.A.Z.G.j.-.w.9.9.9.9.9.9.9.9.9.9.9.9.| X.o.o.o.o.o.o.o.o.o.o.o.+.' S D D D D D D D D D D D D S =.w.8.9.9.9.9.9.9.9.9.9.9.0...X.o.o.o.o.o.o.o.o.o.o.o.+.` ] fXxXlXlX",
"lXhXCXU.! tXyXrXtXtXtXtXtXtXtXtXeXdX|.'.vXaXdXdXdXdXdXdXdXdXdXsXxXX.t k k k k k k k k k k h f B M c n m n n n n n n m b n h ^.bXaXdXdXdXdXdXdXdXdXdXaXvX-.r k h h h h h h h h h h f n | dXxXlXlX",
"lXhXCXY.! 0XqX0X0X0X0X0X0X0X0X0X9XiX[.Q.uX7X8X8X8X8X8X8X8X8X8X7XtXo.k M k j j j j j j j k n n D M b l g g g g g g g g x m j U.iX6X8X8X8X8X8X8X8X8X8X7XuX-.j N m m m m m m m m m m n C } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k k 9 a i p p p p y k S x S M b 9 i p p p p p i p A m j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j a V m M M M M n F J z S N c t N M M M M M M N Y b j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j i m v v v v b x A H z S N v r b v v v v v v b I n j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j p M v b b b b c A H z S N v r b b b b b b b n I n j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j p M v b b b b c A H z S N v r b b b b b b b n I n j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j p M v b b b b c A H z S N v r b b b b b b b n I n j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j p M b b b b n c S H z S N v r n b b b b b b n I n j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k j y n x c c c c z C H z S N v w c c c c c c c v P n j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.! qXwXqXqXqXqXqXqXqXqXqX0XiX{.!.aX9XqXqXqXqXqXqXqXqXqX0XiXo.k k k F A A A A S C P J z S N c a S A A A A A A D T b j T.sX9XqXqXqXqXqXqXqXqXqX9XaX-.g m b b b b b b b b b b v V } dXxXlXlX",
"lXhXCXY.Q 9X9X8X8X8X8X8X8X8X8X8X7XyX].Q.iX7X9X9X9X9X9X9X9X9X9X7XtXo.j m S J H H H H H H J B c S N v V J H J J J J H J S m k U.iX7X9X9X9X9X9X9X9X9X9X7XiX=.g M n n n n n n n n n n b C } dXxXlXlX",
"lXhXCXU.~ dXfXdXdXdXdXdXdXdXdXdXsXxX@X`.xXpXsXsXsXsXsXsXsXsXsXpXlXO.s v l k l k k k k l k x z Z b l l j j j j j j j j k c d ~.cXpXsXsXsXsXsXsXsXsXsXpXcX;.a v x x x x x x x x x c z B | dXxXlXlX",
"lXhXCXT.U A.Z.C.C.C.C.C.C.C.C.C.C.D.f.a.L.D.F.F.F.F.F.F.F.F.F.D.J.[ S J H J J J J J J J J H G I U I I U I I I I I I U I U H u.L.S.F.F.F.F.F.F.F.F.F.D.L...A J H H H H H H H H H H H J { dXxXlXlX",
"lXhXVXW.A k f g f f f f f f f f g f k =.6.4.4.4.4.4.4.4.4.4.4.5.2.&.p.u.u.u.u.u.u.u.u.u.u.u.p.2.=X8X5X5X5X5X5X5X5X5X5X4X0X+X%.6.4.4.4.4.4.4.4.4.4.4.4.3.%.i.u.u.u.u.u.u.u.u.u.u.y.d.=.` gXxXlXlX",
"lXhXVXW.D B m m m m m m m m m m m m M 6.h.s.s.s.s.s.s.s.s.s.s.d.a.;.a.i.i.i.i.i.i.i.i.i.i.i.a.3.1XyXwXeXeXeXeXeXeXeXeXwXiX&X3.h.s.s.s.s.s.s.s.s.s.s.s.s.;.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 3.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.u.i.i.i.i.i.i.i.i.i.u.a.2.,XrX0X0X0X0X0X0X0X0X0X0XtX$X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.d.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 4.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.i.i.i.i.i.i.i.i.i.i.i.a.3.,XrX0XqXqXqXqXqXqXqXqX0XyX%X<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b b n 3.s.u.i.i.i.i.i.i.i.i.i.i.y.-.p.u.i.i.i.i.i.i.i.i.i.u.a.2.>XeX0X0X0X0X0X0X0X0X0X9XtX$X<.s.u.i.i.i.i.i.i.i.i.i.i.u.=.i.i.i.i.i.i.i.i.i.i.i.u.d.-._ gXxXlXlX",
"lXhXVXW.S m v v v v v v v v v v v c b 4.d.i.p.p.p.p.p.p.p.p.p.a.u.;.f.s.d.d.d.d.d.d.d.d.d.s.g.5.3XpXtXyXyXyXyXyXyXyXyXtXsX-X2.g.a.a.a.a.a.a.a.a.a.a.s.a.;.s.a.a.a.a.a.a.a.a.a.a.a.h.;._ gXxXlXlX",
"lXhXVXW.D Z B B B B B B B B B B B B B <.y.e.r.r.r.r.r.r.r.r.r.r.e.@.2.2.2.2.2.2.2.2.2.2.2.2.3.&.|.*X$X%X%X%X%X%X%X%X%X$X-X_.=.0.8.8.8.8.8.8.8.8.8.8.8.8.#.8.8.8.8.8.8.8.8.8.8.8.7.w.#.` fXxXlXlX",
"lXhXCXE.D F A A A A A A A A A A A Z F H Z A Z Z Z Z Z Z Z Z A D m =.^.U.T.T.T.T.T.T.T.T.T.Y.~.u.%.3.<.<.<.<.<.<.<.<.<.<.2.=.@.2.<.<.<.<.<.<.<.<.<.<.<.<.o.<.<.<.<.<.<.<.<.<.<.<.,.3.X.' fXxXlXlX",
"lXhXVXW.S m c c c c c c c c c c v x B C z b n n n n n n n n v b a w.vXiXaXaXaXaXaXaXaXaXaXiXcXL.6.h.s.s.s.s.s.s.s.s.s.s.g.0.2.h.s.s.s.s.s.s.s.s.s.s.d.s.:.d.s.s.s.s.s.s.s.s.s.s.s.j.:._ gXxXlXlX",
"lXhXVXW.S N b b b b b b b b b b n v V Z b j y i i i i i i y j N f 9.aX6X9X9X9X9X9X9X9X9X9X7XpXD.4.s.u.u.u.u.u.u.u.u.u.u.a.8.<.s.u.u.u.u.u.u.u.u.u.u.u.u.=.i.u.u.u.u.u.u.u.u.u.u.y.d.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n r a k j j j j k f F C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n u z M m m m m m v P C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n y k n b b b b b x L C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n y l n b b b b n c L C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n y l n b b b b n c L C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n y l n b b b b n c L C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n u l m b n n n n c L C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V C n t h v x x x x c l K C s 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.S M b b b b b b b b b b b v V Z b h F L K K K K K J E B d 9.dX8XqXqXqXqXqXqXqXqXqX9XsXF.4.s.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.D B m m m m m m m m m m m n Z A v M C C C C C C C Z B M g 9.aX7X9X9X9X9X9X9X9X9X9X7XpXD.4.s.i.i.i.i.i.i.i.i.i.i.s.8.<.d.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXVXW.A k f f f f f f f f f f g s c B k l k k k k k k k k k c u q.vXuXaXaXaXaXaXaXaXaXaXiXcXL.3.s.i.i.i.i.i.i.i.i.i.u.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.u.=.i.i.i.i.i.i.i.i.i.i.i.u.d.-._ gXxXlXlX",
"lXhXCXR.K 1.,.,.,.,.,.,.,.,.,.,.,.<.*./ ` _ ` ` ` ` ` ` ` ` ` ` ) [ ;.=.=.=.=.=.=.=.=.=.=.=.;...%.;.-.-.-.-.-.-.-.-.-.=.;.#.o.:.=.-.-.-.-.-.-.-.-.-.-.=. .-.-.-.-.-.-.-.-.-.-.-.=.:.} ' fXxXlXlX",
"lXhXCXU.~ sXdXdXfXdXdXdXdXdXdXfXaXlX&X3.k.d.f.f.f.f.f.f.f.f.f.d.k.E i h h h h h h h h h h h a A i.i.i.i.i.i.i.i.i.i.i.i.s.8.<.d.i.i.i.i.i.i.i.i.i.i.i.i.-.p.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.Q 9X0X5X2X3X3X3X3X3X3X2X5XtX X,.s.y.u.u.u.u.u.u.u.u.u.y.a.! c M z l l l l l l l l m b J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.d.-._ gXxXlXlX",
"lXhXCXY.! qXqX#X:X:X:X:X:X:X:X>XiXuXXX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c k 8 p u u u u u t h A z H u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X-XtXeXeXeXeXrXeXyXxXtXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h a V m M M M M n F J k J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X=XwX0X0X0X0XqX0XeXlXyXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h i m v v v v b x A H l J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXyXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h p M v b b b b c A H k J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXyXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h p M v b b b b c A H k J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqX0XeXlXyXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h p M v b b b b c A H k J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X=XwXqXqXqXqXqXqXrXlXyXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h p M b b b b n c S H k J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X*X0X9X9X9X9X9X9XqXlXyXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c h u n c c c c v z Z H l J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.! wX0X,XaXiXpXpXpXpXiXsXcXtXoX<.d.u.i.i.i.i.i.i.i.i.i.u.d.Q c j h D C Z Z Z Z V K J k J u.i.i.i.i.i.i.i.i.i.i.i.a.8.<.s.u.i.i.i.i.i.i.i.i.i.i.i.-.i.i.i.i.i.i.i.i.i.i.i.u.f.-._ gXxXlXlX",
"lXhXCXY.Q 9X9XrXhXfXgXgXgXgXfXhXuXrX.X,.s.u.u.u.u.u.u.u.u.u.u.y.s.! z b S K J J J J J J K V x J y.u.u.u.u.u.u.u.u.u.u.u.a.7.,.s.y.u.u.u.u.u.u.u.u.u.u.u.=.u.u.u.u.u.u.u.u.u.u.u.y.d.=.` gXxXlXlX",
"lXhXCXY.~ dXfXaXpXpXpXpXpXpXpXpXpXzX*X3.k.d.f.f.f.f.f.f.f.f.f.d.j.~ k b x z z z z z z z z v z H d.f.d.f.f.f.f.f.f.f.f.d.h.w.3.j.d.f.f.f.f.f.f.f.f.f.f.d.:.f.d.f.f.f.f.f.f.f.f.f.d.k.>.` gXxXlXlX",
"lXhXCXY.P K.J.J.J.J.J.J.J.J.J.J.H.I.c.X.:.-.-.-.-.-.-.-.-.-.-.=.:.R N C C C C C C C C C C C N J =.-.-.-.-.-.-.-.-.-.-.-.;.#.X.:.-.-.-.-.-.-.-.-.-.-.-.-.} -.-.-.-.-.-.-.-.-.-.-.=.>.{ ) fXxXlXlX",
"lXjXVX^.W / ! ! ! ! ! ! ! ! ! ! ! Q ^ ' _ _ _ _ _ _ _ _ _ _ _ _ _ [ | } } } } } } } } } } } | { ` _ _ _ _ _ _ _ _ _ _ _ _ ` ' _ _ _ _ _ _ _ _ _ _ _ _ _ ' _ _ _ _ _ _ _ _ _ _ _ ` ` ) $.fXzXlXlX",
"lXlXlXjXdXhXhXhXhXhXhXhXhXhXhXhXhXhXhXfXgXgXgXgXgXgXgXgXgXgXgXgXgXfXdXdXdXdXdXdXdXdXdXdXdXdXdXdXgXgXgXgXgXgXgXgXgXgXgXgXgXfXfXgXgXgXgXgXgXgXgXgXgXgXgXgXfXgXgXgXgXgXgXgXgXgXgXgXgXgXfXfXlXlXlXlX",
"lXlXlXzXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXzXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlX",
"lXlXkXcXVXBXBXBXBXBXBXBXBXBXBXBXBXBXVXVXVXVXVXVXVXVXVXVXVXVXBXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXBXBXBXBXBXBXBXBXBXBXBXBXVXVXVXVXVXVXVXVXVXVXVXVXVXNXlXlXlXlX",
"lXkXcXqX_.{.[.[.[.[.[.[.[.[.[.[.[.].`.`.`.`.`.`.`.`.`.`.`.`.'.`.`.`.`.`.`.`.`.`.`.`.`.'.).(.(.(.(.(.(.(.(.(.).(._.[.[.[.[.[.[.[.[.[.[.[.[.].).(.(.(.(.(.(.(.(.(.(.(.(..XkXlXlXlX",
"lXjXVX_.M H D D D D D D D D D D D H T T T T T T T T T T Y T I Y T T T T T T T T T T T U ( ` _ _ _ _ _ _ _ _ _ ` Q S D D D D D D D D D D D G ( ` _ _ _ _ _ _ _ _ _ ' R ( hXzXlXlX",
"lXjXBX{.H B m m m m m m m m m M v U d.a.a.a.a.a.a.a.a.a.a.f.2.r.d.a.a.a.a.a.a.a.a.a.d.7.1XuXeXeXeXeXeXeXeXeXqXfXY.k N m m m m m m m m M b G <XuXrXtXtXtXtXtXtXtXwXfX~.' kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrXqXqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n x D >XtX6X4X5X5X5X5X5X4X6XsXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.p.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D >XwX$X<X,X,X,X,X,X,XuXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX:XtXeXeXeXeXeXrXlXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX-XwX0XqXqXqX0XqXjXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX;XeXqXqXqXqXqXwXjXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX;XeXqXqXqXqXqXwXjXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX;XeXqXqXqXqXqXwXjXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX-XwX0X0X0X0X0X0XjXaXW._ kXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XsXI.h m b b b b b b b b n c D ,XqX>XuXtXtXtXtXtXyXzXaXW._ kXzXlXlX",
"lXjXBX[.D N n n n n n n n n n m c P i.u.u.u.u.u.u.u.u.u.y.a.,.w.p.i.i.i.i.i.i.i.i.i.a.5.:XqX8X8X8X8X8X8X8X8X6XiXL.j m b b b b b b b b n c D :XqXrXjXhXhXhXhXhXjXaXiXE._ kXzXlXlX",
"lXjXBX[.S x k k k k k k k k k l f J g.f.f.f.f.f.f.f.f.f.d.j.2.w.a.i.i.i.i.i.i.i.i.i.a.6.0XjXdXdXdXdXdXdXdXdXaXbXQ.f n v v v v v v v v v z S 4XdXyXyXyXyXyXyXyXyXrXlX/._ kXzXlXlX",
"lXjXBX].J ^ ! ! ! ! ! ! ! ! ! ! Q ^ $.$.$.$.$.$.$.$.$.$.$.%...4.9.8.8.8.8.8.8.8.8.7.0.-.k.M.n.n.n.n.n.n.n.n.b.V.9.V S A A A A A A A A S Z K D.Y.I.I.I.I.I.I.I.I.P.W.d.] kXzXlXlX",
"lXjXVX(._ eXqXwXwXwXwXwXwXwXwX8XdXn.p v z z z z z z z z x g U 2X5X4X5X5X5X5X5X5X5X2XtXA.t g g g g g g g g g g a m C n N N N N N N N N N b F OX1X:X>X>X>X>X>X>X>X;X6XK.` kXzXlXlX",
"lXjXVX(._ rXqX6X5X6X5X5X5X6X5X7XfXm.f M n n n n n n n n m z R 0XrXwXeXeXeXeXeXeXeX0XfXH.j N x l z z z z z l b n S M v l h j j j j j h x x S 1XiXeXrXrXrXrXrXrXrXwXgX~._ kXzXlXlX",
"lXjXVX(._ tX5X%X,X>X>X>X>X:X1XuXsXn.f m b b b b b b b b n l T 8XwX0XqXqXqXqXqXqXqX8XsXG.h c 0 a p p p p p a Z c Z B z 0 a p p p p p p Z c D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX4X<XyXeXeXeXeXwXiXhXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x p B m M M M m B I x A B l i B m M M M m N I z D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX5X,XeX0XqXqXqX0XrXgXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x u m v v v v v n L x Z B l u m v v v v v n L x D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX5X,XeXqXqXqXqX0XtXgXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x i m v b b b b m L x Z B l u m v b b b b n P x D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX5X,XeXqXqXqXqX0XtXgXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x i m v b b b b m L x Z B l u m v b b b b n P x D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX5X,XeXqXqXqXqX0XtXgXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x i m b b b b b m L x Z B l u m b b b b b n P x D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX5X>XwX0X0X0X0X9XrXgXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x u n v v v v v n L x Z B l u n v v v v v b L x D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ tX4X1XuXrXrXrXrXeXpXjXaXm.f m b b b b b b b b n l T 8XwXqXqXqXqXqXqXqXqX9XdXG.h x p V M M M M M B I x A B l p V M M M M M B U z D >XrX0XqXqXqXqXqXqXqX9XaXW._ kXzXlXlX",
"lXjXVX(._ wX8XiXkXhXhXhXhXhXkXuXpXn.g M n n n n n n n n m z R 5X0X8X8X8X8X8X8X8X8X6XpXD.h b C P K K K K K P F x A B c C I L L L L L I H x F ;XwX8X8X8X8X8X8X8X8X7XiXE._ kXzXlXlX",
"lXjXVX(.` sXpXuXyXuXuXuXuXuXyXrXcXB.u c l l l l l l l l z f Y pXfXdXdXdXdXdXdXdXdXpXbXU.d n c z x x x x x z x x C v k l j j j j j j j k h C 8XjXsXdXdXdXdXdXdXdXaXvX_._ kXzXlXlX",
"lXjXVX_.Q R.Y.Y.Y.Y.Y.Y.Y.Y.Y.I.~.q.K E T T T T T T T T R Y / B.Z.C.C.C.C.C.C.C.C.V.G.9.N S A A A A A A A A S Z J E T R R R R R R R R R T W v.A.C.C.C.C.C.C.C.C.V.G.r.[ jXzXlXlX",
"lXjXVX).( >X-X-X-X-X-X-X-X-X-X=X1XS.;XqX8X8X8X8X8X8X8X8X5XpXB.r h g h h h h h h h g s M C m N N N N N N N N N b K >X0X7X8X8X8X8X8X8X8X6XuXT.i g f f f f f f f f g d z o.hXzXlXlX",
"lXjXVX(.` uXtXtXtXtXtXtXtXtXtXeXdXY.,XtXwXwXwXwXwXwXwXwX0XfXZ.h N c z z z z z z z b n S M v l j k j j j k j c z H 3XtXqXwXwXwXwXwXwXwX0XsXW.l N m m m m m m m m m m B X.hXzXlXlX",
"lXjXVX(._ eXqX0XqXqXqXqXqXqXqX9XiXI.:XrX0XqXqXqXqXqXqXqX8XdXC.g c 0 p i i i i i p Z c A N z 0 p i i i i i p Z x H 1XeX0XqXqXqXqXqXqXqX8XaXE.j n b b b b b b b b b b M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z p B m m m M m B P x A B k p B m m m M m B I l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z i m v v v v v m K x A B k u m v v v v v n L l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z i m v b b b v M L x A B k i m v b b b b m P l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z i m v b b b v M L x A B k i m v b b b b m P l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z i M v b b b v M L x A B k i m b b b b b m P l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z i m v v v v v m K x A B k u m v v v v v n L l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX(._ eXqXqXqXqXqXqXqXqXqX9XiXI.>XrXqXqXqXqXqXqXqXqX8XdXC.h z p B m M M M m B P x A B k p B m M M M m B I l J 2XrX0XqXqXqXqXqXqXqX9XaXE.j n b b b b b b b b b v M X.hXzXlXlX",
"lXjXVX)._ qX9X8X9X9X9X9X9X9X9X7XtXL.;XwX9X9X9X9X9X9X9X9X6XaXV.g n Z I L L L L L I G c A B c Z I L L L L L I H z J <XqX8X9X9X9X9X9X9X9X7XiXR.k m n n n n n n n n n b N X.hXzXlXlX",
"lXjXVX(.' gXdXsXdXdXdXdXdXdXdXaXzXW.6XgXaXaXaXaXaXaXaXaXiXvXF.a b x l z z z z z l z z C b l z k k k k k k k l h F 0XfXaXaXaXaXaXaXaXaXiXxX/.f v x x x x x x x x c x n X.hXzXlXlX",
"lXjXVX_.W J.G.G.G.G.G.G.G.G.G.F.L.u.S.I.L.P.P.P.P.P.P.P.K.E.w.C H G H H H H H H H H F P U P P I I I I I I I I L E D.I.L.P.P.P.P.P.P.P.K.R.d.A H G G G G G G G G G G F ..hXzXlXlX",
"lXjXBX[.S j g g g g g g g g g h a F 7.4.4.4.4.4.4.4.4.4.4.6.&.w.i.u.u.u.u.u.u.u.u.u.p.4.*X8X4X5X5X5X5X5X5X5X3XrXL.&.7.4.4.4.4.4.4.4.4.4.7.*.9.p.u.u.u.u.u.u.u.u.y.s.>.} jXzXlXlX",
"lXjXBX[.D N m m m m m m m m m M v I d.s.s.s.s.s.s.s.s.s.s.g.1.w.a.i.i.i.i.i.i.i.i.i.a.5.1XyXwXeXeXeXeXeXeXeXqXdXR.7.h.s.s.s.s.s.s.s.s.s.h.4.9.s.i.i.i.i.i.i.i.i.i.f.,.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.p.i.i.i.i.i.i.i.i.u.p.5.>XrX0X0X0X0X0X0X0X0X8XpXY.4.s.i.i.i.i.i.i.i.i.u.s.1.9.a.u.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b n x P p.i.i.i.i.i.i.i.i.i.u.s.,.w.a.i.i.i.i.i.i.i.i.i.a.5.,XrX0XqXqXqXqXqXqXqX9XaXY.4.s.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D M b b b b b b b b b n x P i.u.u.u.u.u.u.u.u.u.y.a.,.w.p.u.i.i.i.i.i.i.i.u.p.5.:XwX8X9X9X9X9X9X9X9X7XiXU.3.s.u.u.u.u.u.u.u.u.u.a.1.8.a.u.u.u.u.u.u.u.u.u.s.>.} jXzXlXlX",
"lXjXBX[.D n c v v v v v v v v v l L f.d.d.d.d.d.d.d.d.d.s.h.2.r.d.a.a.a.a.a.a.a.a.a.d.7.7XfXpXaXaXaXaXaXaXaXiXxX!.6.h.s.s.s.s.s.s.s.s.a.g.4.q.f.s.s.s.s.s.s.s.s.a.h.1.{ jXzXlXlX",
"lXjXBX[.F D Z Z Z Z Z Z Z Z Z A V U ,.>.>.>.>.>.>.>.>.>.>.<.+.<.5.4.4.4.4.4.4.4.4.4.5.=.G.E.Y.Y.Y.Y.Y.Y.Y.Y.U.!.f.%.3.1.1.1.1.1.1.1.1.<.3.$.-.2.1.1.1.1.1.1.1.1.<.4.O.| jXzXlXlX",
"lXjXBX[.F V N N N N N N N N N N M D b c v v v v v v v v b k U *X:X-X;X;X;X;X;X;X;X=X4XZ.&.6.4.4.4.4.4.4.4.4.3.6.%.4.q.0.0.0.0.0.0.0.0.9.e.;.2.w.0.0.0.0.0.0.0.0.9.r.*.} jXzXlXlX",
"lXjXBX[.D n v v v v v v v v v v c A M b c z z z z z z z b z R wXyXrXtXtXtXtXtXtXtXeXgXU.7.h.s.s.s.s.s.s.s.s.s.h.3.q.d.a.a.a.a.a.a.a.a.p.f.3.0.d.a.a.a.a.a.a.a.a.p.g.<.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N l 0 i u u u u u p C l R 7XqX0X0X0X0X0X0X0X0X8XaXL.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.u.i.i.i.i.i.i.i.u.s.1.9.a.u.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N h a B m m m m n V I j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N j p m v v v b v M L j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N j p M v b b b v M L j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N j p M v b b b v M L j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N j p M v b b b v M L j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N j p m v b b b v M L j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D m b b b b b b b b b b v A N h p N n n n n b B I j R 8XwXqXqXqXqXqXqXqXqX9XaXP.4.s.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXBX[.D M n n n n n n n n n n v S M x Z I L L L P L U H k R 6X0X8X9X9X9X9X9X9X9X7XiXK.4.s.u.u.u.u.u.u.u.u.u.a.<.9.p.u.u.u.u.u.u.u.u.u.a.1.8.a.u.u.u.u.u.u.u.u.u.s.>.} jXzXlXlX",
"lXjXBX[.D b x c c c c c c c c c z Z n c c x x x x x x x c j T uXsXaXaXaXaXaXaXaXaXiXxXR.7.h.s.s.s.s.s.s.s.s.a.g.3.e.f.s.s.s.s.s.s.s.s.a.g.4.q.f.s.s.s.s.s.s.s.s.a.h.1.{ jXzXlXlX",
"lXjXBX].G G D D D D D D D D D D S K D A A A A A A A A A S V E T.W.E.E.E.E.E.E.E.E.R./.d.*.4.1.2.2.2.2.2.2.2.1.4.$.;.3.1.2.2.2.2.2.2.2.1.4.$.-.3.1.2.2.2.2.2.2.2.1.5.+.} jXzXlXlX",
"lXjXVX).( <X>X>X,X,X,X,X,X,X,X;X6XM.3.u.r.r.r.r.r.r.r.r.e.i.$.g k k k k k k k k k l f A 9.9.9.9.9.9.9.9.9.9.8.q.-.2.0.9.9.9.9.9.9.9.9.8.q.-.1.q.9.9.9.9.9.9.9.9.8.w.&.} jXzXlXlX",
"lXjXVX(.` uXtXwXqXqXqXqXqXqXqXqXgXF.7.d.p.p.p.p.p.p.p.p.i.g.=.c m b c c c c c c c b v H p.s.a.a.a.a.a.a.a.a.a.f.2.w.d.a.a.a.a.a.a.a.a.a.f.3.q.f.a.a.a.a.a.a.a.a.p.h.<.{ jXzXlXlX",
"lXjXVX(._ rX6X$X:X-X;X;X;X-X>XrXpXA.6.a.i.i.i.i.i.i.i.i.u.d.*.c x q i y u u u y i V x G u.i.u.i.i.i.i.i.i.i.u.s.1.0.a.u.i.i.i.i.i.i.i.u.s.1.9.a.u.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX4X<XtXwXeXeXeXwXuXjXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c k p B n m m m n B I l H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX5X,XeX0XqXqXqX0XtXgXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c l i m v b b b v m L z H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX5X,XeXqXqXqXqX0XtXhXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c l i m v b b b v M L z H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX5X,XeXqXqXqXqX0XtXhXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c l i m v b b b v M L z H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX5X,XeXqXqXqXqX0XtXhXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c l i m v b b b v M L z H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX5X,XeX0XqXqXqX0XtXgXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c l i m v b b b v m L z H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ tX4X,XrXqXwXwXwX0XyXjXiXS.6.s.i.i.i.i.i.i.i.i.u.f.*.c k i M b n n n b M P z H u.i.i.i.i.i.i.i.i.i.u.s.1.0.a.i.i.i.i.i.i.i.i.u.s.2.9.a.i.i.i.i.i.i.i.i.u.d.>.{ jXzXlXlX",
"lXjXVX(._ wX6XuXlXjXjXjXjXjXzXpXyXA.6.a.u.u.u.u.u.u.u.u.y.d.&.c c C I L L L L L I J z H y.i.u.u.u.u.u.u.u.u.u.a.<.9.p.u.u.u.u.u.u.u.u.u.a.1.8.p.u.u.u.u.u.u.u.u.u.s.>.} jXzXlXlX",
"lXjXVX(.' fXsXaXaXaXaXaXaXaXaXuXxXJ.0.h.d.d.d.d.d.d.d.d.s.k.;.z b b v v v v v v v v x G s.f.d.d.d.d.d.d.d.d.s.h.4.r.g.d.d.d.d.d.d.d.d.s.h.5.w.h.d.d.d.d.d.d.d.d.s.j.2.} jXzXlXlX",
"lXjXVX(.R ~.W.W.W.W.W.W.W.W.W.E.).y.$.<.>.>.>.>.>.>.>.>.>.2.| n N M M M M M M M M N n F >.,.>.>.>.>.>.>.>.>.>.1.O.*.<.>.>.>.>.>.>.>.>.>.1.+.&.<.>.>.>.>.>.>.>.>.>.2...] jXzXlXlX",
"lXjXNX.X( ' _ _ _ _ _ _ _ _ _ _ _ [ } { { { { { { { { { } { | X.X.X.X.X.X.X.X.X.X.X.X...} { { { { { { { { { } { | } { { { { { { { { { } { } } { { { { { { { { { } } ] >.jXzXlXlX",
"lXlXlXkXhXkXkXkXkXkXkXkXkXkXkXkXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXhXhXhXhXhXhXhXhXhXhXhXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlX",
"lXlXlXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlX",
"lXlXlXlXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXvXvXvXvXvXvXvXvXvXcXcXcXcXcXcXcXcXcXvXvXvXvXvXvXvXvXvXcXlXlXlXlX",
"lXlXlXkXuXuXiXiXiXiXiXuXiXuXrXrXrXrXrXrXrXrXtXtXrXrXrXrXrXrXrXtXwXqXqXqXqXqXqXqXqXuXiXuXiXiXiXiXuXiXeX0XqXqXqXqXqXqXqXyXkXlXlXlX",
"lXkXcXuX| Q ^ ^ ^ ^ ^ ^ ~ ( X.X.X.X.X.X.X.X. . .X.X.X.X.X.X.X. .-.<.,.,.,.,.,.<.:.( ~ ^ ^ ^ ^ ^ ^ ! $.1.,.,.,.,.,.<.:.O.yXcXkXlX",
"lXkXcXuXQ l c x x x x c k F u.u.u.u.u.u.y.p.6.0.i.y.u.u.u.u.p.7.@XuX0XqXqXqXqXrX<XA k c x x x x v d I.dX8X0X0X0X0X0XwX:.qXvXkXlX",
"lXkXcXiX^ c n n n n n n c J p.p.i.i.i.i.i.s.8.w.a.i.i.i.i.i.a.9.@XyX0XqXqXqX0XrX<XF c n n n n n m h T.tX;X1X<X1X,XwXeX,.qXvXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.u.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XrX<XF x n b b b b m g Y.wX4XeXqXwXqXgXwX,.qXvXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.i.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XrX<XF x n b b b b m g Y.eX3XwXqXqX0XfXwX,.qXvXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.i.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XrX<XF x n b b b b m g Y.eX4XwXqXqX0XfXwX,.qXvXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.i.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XrX<XF x n b b b b m g T.eX2XqX9X0X8XdXeX,.qXvXkXlX",
"lXkXcXuX^ v m n n n n m c J u.u.u.u.u.u.u.p.6.q.a.i.i.i.i.i.a.8.OXrX8X9X9X9X8XwX>XF x n b b b b m h Y.eX8XuXtXyXtXhXqX,.qXvXkXlX",
"lXkXcXiX~ h l l l l l z g D f.d.d.d.d.d.d.g.0.q.a.i.i.i.i.i.a.8.;XjXaXsXsXsXaXgX9XD z b v v v v n f R.kXdXhXhXhXhXgXuX<.qXvXkXlX",
"lXkXcXuX_ Y R R R R R R T ! :.>.:.:.:.:.:.>.%.9.y.r.r.r.r.r.y.6.B.R.I.U.U.U.I.T.G.H N V V V V V Z b v.oX`.'.'.'.'.].[.*.wXvXkXlX",
"lXkXvXqX,.9X0X9X9X9X9X6XiXP.d v x x x x c k A *X6X3X4X4X4X3X9X.Xz g h h h h h f z C m M m m m m M l F.7X;X>X>X>X>X,X>X:.qXvXkXlX",
"lXkXvXqX,.wX<X<X1X1X<X2XgXU.h m n n n n n c F 2XyXwXeXeXeXwXiX$XV h s f f f d m B V g i s a a p n h T.gXwXrXrXrXrXrXtX<.qXvXkXlX",
"lXkXvXqX,.0X,XqX0XqX9XtXxXP.h m b b b b n x F <XeX0XqXqXqX9XyX@XN a c n b b n F m C s z n b b b J h U.aX8XqXqXqX0XqXqX,.qXvXkXlX",
"lXkXvXqX,.0X1XwXqXqX0XtXzXP.h m b b b b n x F <XrX0XqXqXqX0XyX@XN s c n b b n D m C d z n b b b H h U.sX9XqXqXqXqXqXqX,.qXvXkXlX",
"lXkXvXqX,.0X1XwXqXqX0XtXzXP.h m b b b b n x F <XrX0XqXqXqX0XyX@XN s c n b b n D m C d z n b b b H h U.sX9XqXqXqXqXqXqX,.qXvXkXlX",
"lXkXvXqX,.0X<X0X0X0X9XrXzXP.h m b b b b n x F <XrX0XqXqXqX0XyX@XN a x b v v b D m C d l b v v v G h U.sX9XqXqXqXqXqXqX,.qXvXkXlX",
"lXkXvXqX,.9X2XtXrXrXeXiXzXL.j M n n n n n c F >XwX9X9X9X9X8XrX+XN d m B N N V G m Z f n V B B B L h I.pX7X9X9X9X9X0X0X,.qXvXkXlX",
"lXkXvXqX<.yXsXkXkXkXkXhXxXR.d v x x x x c k S 7XdXiXpXpXpXuXgX-Xm v A A A A S B m M z C C C C Z C s W.zXyXpXpXpXiXpXpX<.0XvXkXlX",
"lXkXvXwX=. X X}.}.}.|.{.#Xm.B G F F F F F S I Q.[.`.`.`.`.`.}.P.Z N N M M M M N Z H D S S S S S F V c..X_.'.'.'.'.'.`.*.wXvXkXlX",
"lXkXvXwX;.*X*X*X*X*X*X&X:XE.#X3X<X<X<X<X>X7XQ.j c x x x x x l n C N B B B B B N b Q.7X,X<X<X<X<X1X>XI g x z z z z x j ~ iXcXkXlX",
"lXkXvXqX<.yXyXtXtXtXtXrXsX|.1XuXeXrXrXrXwXdX[.c h s d d d d n B B f p s a a a b z [.dXwXrXrXrXeXtXwXE l m n n n n n c ^ uXcXkXlX",
"lXkXvXqX,.qXqX0X0X0X0X9XyX].:XeX0X0X0X0X9XiX`.x s c v v c m D M V a z b v v b G l `.iX9X0X0X0X0XqX8XR l n b b b b n c ^ iXcXkXlX",
"lXkXvXqX,.qXqXqXqXqXqX0XuX[.>XrXqXqXqXqX9XpX`.x d v n b b M S M V s c n b b m F l '.pX9XqXqXqXqXwX9XR l n b b b b n x ^ iXcXkXlX",
"lXkXvXqX,.qXqXqXqXqXqX0XuX[.>XrXqXqXqXqX9XpX`.x d v b b v M S M V s c n b b n F l '.pX9XqXqXqXqXwX9XR l n b b b b n x ^ iXcXkXlX",
"lXkXvXqX,.qXqXqXqXqXqX0XuX[.>XrXqXqXqXqX9XpX`.x d c b v v m S M V s x b v v n F l '.pX9XqXqXqXqXwX9XR l n b b b b n x ^ iXcXkXlX",
"lXkXvXqX,.0X0X0X0X0X0X9XtX].:XeX0X0X0X0X8XuX`.x d m M M m V F M V s n N M M B H l `.uX8X0X0X0X0XqX8XR l n b b b b n c ^ iXcXkXlX",
"lXkXvXqX<.uXyXyXyXyXyXtXdX X3XaXyXyXyXyXrXgX}.l n D S S S F B M N c S S S S D Z k }.gXrXyXyXyXyXuXrXR k b v v v v b z ~ iXcXkXlX",
"lXkXvXwX-.#X#X#X#X#X#X@X*XU.].%X@X@X@X@X+X=XP.b N m m m m m m C C m m n n n n m b P.=X+X@X@X@X@X#XOXR v B N N N N N n ^ uXcXkXlX",
"lXkXcXuX^ b M M M M M M b J 8.8.8.8.8.8.8.0.,.4.q.0.0.0.0.0.w.1.^.*X@X#X#X#X#X&X].2.9.8.8.8.8.8.9.4.,.w.9.0.0.0.0.0.8. .tXcXkXlX",
"lXkXcXiX~ z b v v v v b z H a.a.a.a.a.a.a.d.9.e.d.a.a.a.a.a.d.0.&XdXtXyXyXyXtXaX1Xw.s.a.a.a.a.a.s.t.7.d.p.a.a.a.a.a.p.X.rXcXkXlX",
"lXkXcXiX^ c n b b b b n x H i.i.i.i.i.i.u.a.7.q.p.u.i.i.i.u.a.8.+XtX9X0X0X0X9XeX-X0.p.i.i.i.i.i.p.e.5.a.u.i.i.i.u.i.y.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.i.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XtX;X0.p.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.i.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XtX;X0.p.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.i.a.7.q.a.i.i.i.i.i.a.8.@XyX0XqXqXqX0XtX;X0.p.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b n x H i.i.i.i.i.i.u.a.7.q.p.i.i.i.i.i.a.8.+XyX9X0X0X0X0XrX;X0.p.i.i.i.i.i.p.e.5.a.u.i.i.i.i.i.y.X.rXcXkXlX",
"lXkXcXiX~ x b v v v v b z H p.p.p.p.p.p.i.s.8.e.d.a.a.a.a.a.f.0.%XaXeXtXtXtXrXiX<Xw.s.p.a.a.a.a.s.t.7.d.p.a.a.a.a.a.i.X.rXcXkXlX",
"lXkXcXuX^ n N M M M M N n K t.r.r.r.r.r.r.u.4.1.9.7.7.7.7.7.9.,.'.1X-X;X;X;X;X<XXX5.w.q.q.q.q.q.w.7.<.e.q.q.q.q.q.w.0. .tXcXkXlX",
"lXkXcXuX/ M V B B B B B N S S A S S S S D V L ^.|.[.{.{.{.[..XU.2.w.0.0.0.0.0.w.5.,.9.7.7.7.7.7.8.3.:.9.7.7.7.7.7.8.6. .tXcXkXlX",
"lXkXcXiX~ z b v v v v v c B n f a s s s d l D 6XsXuXiXiXiXuXfX=X9.s.p.p.p.p.p.s.w.9.d.a.a.a.a.a.s.t.7.d.a.a.a.a.a.s.p.X.rXcXkXlX",
"lXkXcXiX^ c n b b b b b v V M i z z z l n C D ,XwX9X0X0X0X8XtX+X8.a.i.i.i.i.i.p.q.7.a.u.i.i.i.u.p.e.5.a.u.i.i.i.u.i.y.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b b v V m s n n n b V C S <XrX0XqXqXqX0XyX@X8.a.i.i.i.i.i.a.q.7.a.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b b v V m a b b b v B C S <XrX0XqXqXqX0XyX@X8.a.i.i.i.i.i.a.q.7.a.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b b v V m a b b b v B C S <XrX0XqXqXqX0XyX@X8.a.i.i.i.i.i.a.q.7.a.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXiX^ x n b b b b b v V m p b b b v B Z S <XeX0XqXqXqX0XyX@X8.a.i.i.i.i.i.a.q.7.a.u.i.i.i.i.p.e.5.a.u.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXcXuX^ v m m m m m m n C m b G F G F K B D 1XtXqXwXwXwXqXuX#X9.s.p.p.p.p.p.s.w.8.s.p.p.p.p.p.a.r.6.s.p.p.p.p.p.a.i.X.rXcXkXlX",
"lXkXcXiX! d h g g g g h f b b x x x x x c k S >XqX8X8X8X8X7XrXOX4.t.e.e.e.e.e.t.7.3.t.e.e.e.e.e.r.9.2.t.e.e.e.e.e.r.w...tXcXkXlX",
"lXkXvXeX$.I.T.Y.Y.Y.T.U.W.j.%.,.:.:.:.:.:.,.#.T E W W W W W R R ,.7.5.5.5.5.5.7.<.:.7.5.5.5.5.5.6.2.;.7.5.5.5.5.5.6.4.| tXcXkXlX",
"lXkXvX0X1.dXtXwXeXeXeXwXzX'.q.h.d.d.d.d.s.h.7.z d i p p p p j b q.d.a.a.a.a.a.d.e.9.d.a.a.a.a.a.s.t.7.d.a.a.a.a.a.s.p.X.rXcXkXlX",
"lXkXvXqX,.8X;X4X3X4X2X8XgXW.7.a.u.u.u.u.y.a.3.m a k z l l c A N 0.p.u.i.i.i.u.p.q.7.a.u.i.i.i.u.p.e.5.a.u.i.i.i.u.i.y.X.rXcXkXlX",
"lXkXvXqX,.0X1XeXwXwXqXyXlXQ.8.a.i.i.i.i.u.s.4.n s b m n n N D m 0.a.i.i.i.i.i.a.q.7.a.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXvXqX,.0X<XqXqXqX9XtXkXQ.8.a.i.i.i.i.u.s.4.n s v b b v M S m 0.a.i.i.i.i.i.a.q.7.a.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXvXqX,.0X1XwXqXqX0XtXkXQ.8.a.i.i.i.i.u.s.4.n s v n b b M S m 0.a.i.i.i.i.i.a.q.7.a.i.i.i.i.i.p.e.5.a.i.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXvXqX,.0X,XqX0X0X8XtXlXQ.8.a.i.i.i.i.u.s.4.n a c b v c m D m 0.a.u.i.i.i.i.a.q.7.a.u.i.i.i.i.p.e.5.a.u.i.i.i.i.i.u.X.rXcXkXlX",
"lXkXvXqX<.0XwXgXfXfXdXgXjX!.8.s.i.i.i.i.i.d.4.b c G F F F J S M q.a.i.i.i.i.i.a.w.8.s.i.i.i.i.i.a.r.6.s.i.i.i.i.i.p.u.X.rXcXkXlX",
"lXkXvXqX:.wXeXwXwXwXeX0XpX~.6.p.u.u.u.u.y.a.2.x c v c c c v z n 8.p.y.u.u.u.y.i.0.6.p.y.u.u.u.u.i.w.4.p.y.u.u.u.u.u.t. .rXvXkXlX",
"lXkXcXyXO.:.,.,.,.,.,.,.1.%. .X.X.X.X.X...X.| ^ ~ ~ ~ ~ ~ ~ ^ ^  .X.X.X.X.X.X.X. . .X.X.X.X.X.X.X...| X.X.X.X.X.X.X. .X.uXcXkXlX",
"lXlXlXkXyXqXqXqXqXqXqXqX0XeXtXrXrXrXrXrXrXrXtXiXiXiXiXiXiXiXiXuXtXrXrXrXrXrXrXrXtXtXrXrXrXrXrXrXrXtXtXrXrXrXrXrXrXrXrXuXkXlXlXlX",
"lXlXlXlXcXvXvXvXvXvXvXvXvXvXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXvXcXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlX",
"lXlXlXzXnXbXbXbXbXbXbXmXmXmXmXmXmXnXmXmXmXmXmXmXMXMXMXMXMXMXnXbXbXbXbXbXnXMXMXMXMXMXMXnXlXlXlXlX",
"lXlXzXgX4X5X5X5X5X5X4X<X,X,X,X,X,X<X,X,X,X,X,X<X=X*X*X*X*X&X1X6X5X5X5X5X4X=X*X*X*X*X&X3XlXlXlXlX",
"lXkXnX4XL S F D D S K &.*.*.*.*.&.+.*.*.*.*.*.&.v.V.N.N.M.A.| V F D F S P v.C.N.B.B.N.6.pXxXlXlX",
"lXkXbX5XS z v c v z A a.d.d.d.d.s.q.f.d.d.d.d.p.0XgXaXsXpXcX>.a b c v l F 9XtXeXeXeXkXx.tXcXlXlX",
"lXkXbX5XF v n n n c S t.i.u.u.i.y.7.i.u.u.u.u.t.,XwX8X9X7XiX;.g M n n x H ;X5X9X7X0XaXj.yXcXlXlX",
"lXkXbX5XD c n b n c S y.p.i.i.i.u.8.p.i.i.i.i.y.<XrX0XqX9XsX;.f m b n x G >X8XwX0XeXdXj.tXcXlXlX",
"lXkXbX5XF v m n n v S t.i.u.u.i.y.7.p.i.i.i.i.y.,XwX9X9X7XpX-.f m b n x H :X6X0X8XqXdXj.tXcXlXlX",
"lXkXbX5XA k x z x k C p.d.s.s.s.a.8.p.i.i.i.i.y.7XsXiXiXyXlX>.s n v b z G 3XsXgXfXgXjXl.tXcXlXlX",
"lXkXnX4XU K P L L K Y 2.5.4.4.4.2.3.i.y.y.y.u.w.~.}.[.[.].oX+.z C B V m H  X=X%X%X%X*Xs.yXcXlXlX",
"lXkXMX=Xn.wX>X1X,X9X(.z b b b m d f.eX,X2X<X8X(.l j j h h z V n c c v x H #X<X>X>X>X2Xf.yXcXlXlX",
"lXkXMX*XV.rX4X8X4XfX}.z n b b M s x.hXqXeXwXaX Xl f l j z V B d h k j v H 3XuXeXrXeXiXl.tXcXlXlX",
"lXkXMX*XN.eX9XwX9XkX[.z n b b M d l.dX8X0X9XuX}.k l M n B Z N h n m n V H <XeX0XqX0XtXk.tXcXlXlX",
"lXkXMX*XB.eX7X0X7XjX{.z n b b M s l.fX8XqX9XiX|.k j n c m C B g c v v N H 1XrX0XqX0XtXk.tXcXlXlX",
"lXkXMX*XB.tXwXtXeXzX{.v M M M B g l.aX6X9X7XyX{.k z B m V Z B l B V V S K ,XwX8X9X8XeXk.tXcXlXlX",
"lXkXMX*Xm.pXeXtXrXdX_.p d d s g 9 x.bXuXaXiXkX+Xx B Z C Z B v s z l x g N 0XfXpXaXpXhXx.tXcXlXlX",
"lXkXMX-Xf.&X|. X|.+XT.s.x.l.l.l.x.>.&.=.=.=.-.O.V B N B B c %.n.j.k.k.x.u.$.=.*.*.=.%.&.dXxXlXlX",
"lXkXMX*XB.fXqXeXeXuX&X9XjXdXfXaXbX&.5 y t r p x b d h g l s c.mXaXfXsXxX%Xd f f f h u ( jXzXlXlX",
"lXkXMX*XN.aX8X0X0XtX#X;XqX8X8X6XuX=.y m m b A Z c h n c B z f.aX6X8X7XtX}.n m m m M x ' hXzXlXlX",
"lXkXMX*XN.sX9XqX0XtX$X,XrXqXqX9XaX=.t m n b C V c j m v V l g.fX8XqX0XuX Xv b b b n k ` hXzXlXlX",
"lXkXMX*XN.pX7X9X9XrX#X:XeX9X0X8XpX=.r n b v Z C v j n v V x g.dX7X0X8XyX|.v n n b m l ` hXzXlXlX",
"lXkXMX*XZ.lXyXiXuXdX;X4XaXyXuXrXjX=.i Z V V Z M z c V N A g j.zXrXuXtXfXOXx c c c v h _ hXzXlXlX",
"lXkXMX-Xs.+X[.}.{..XR.`.+XXXoX.X&X$.m F S D A D K K K K P V u.=X.XoXXX$XY.C A A A S N [ hXzXlXlX",
"lXkXbX5XS l c c c l C 9.q.0.0.q.9.4.y.t.t.t.t.e.*X5X2X2X2X7Xk.6.q.0.0.w.4.0.y.t.t.y.r.,.sXxXlXlX",
"lXkXbX5XD c n b n c S i.a.p.a.a.p.8.a.p.p.p.p.u.2XyXeXeXwXuXm.t.s.a.p.s.w.e.a.p.p.p.i.<.aXxXlXlX",
"lXkXbX5XD c n b n c S y.i.i.i.i.u.7.p.i.i.i.i.y.<XeX0X0X0XrXb.e.p.i.i.p.0.e.p.i.i.i.u.<.aXxXlXlX",
"lXkXbX5XD c n b n c S y.p.i.i.i.u.8.p.i.i.i.i.y.<XrX0XqX0XtXn.r.p.i.i.a.0.e.p.i.i.i.u.<.aXxXlXlX",
"lXkXbX5XD c n b b c S t.i.u.u.u.y.8.s.p.a.a.a.u.<XeX0X0X9XrXn.r.p.i.i.a.q.e.p.i.i.p.u.<.aXxXlXlX",
"lXkXbX5XD v n b n c S a.f.d.f.f.f.5.q.q.q.q.0.0.4XiXrXtXrXpXn.w.i.u.u.p.0.w.i.u.u.u.y.<.sXxXlXlX",
"lXkXbX5XH M V B B N S ^ / ^ / ( T 0.T.J.K.K.I.M.k.m.b.n.n.n.7.7.8.8.7.9.1.3.9.7.8.8.6.;.sXxXlXlX",
"lXkXbX5XD c b b b v N z i a p f u x.cXtXiXuXgX$X6.t.e.r.r.w.7.a.i.p.i.a.q.e.a.p.p.p.i.<.aXxXlXlX",
"lXkXbX5XD c n b b v B v j m v V x k.sX7X9X8XtXXXq.s.p.p.p.i.8.i.i.i.i.p.0.e.p.i.i.i.u.<.aXxXlXlX",
"lXkXbX5XD c n b b v B c k m v V l k.fX8XqX0XuXoX0.a.i.i.i.u.8.p.i.i.i.a.0.e.p.i.i.i.u.<.aXxXlXlX",
"lXkXbX5XF v n n n b V c h n c B z j.sX7X0X8XtXXX0.p.i.i.i.u.7.i.i.i.u.p.0.w.p.u.i.i.u.<.aXxXlXlX",
"lXkXbX5XS l x x x z m c b C B D h x.xXtXuXyXfX$Xw.s.p.a.a.p.9.a.p.a.p.s.w.r.s.p.a.a.p.<.aXxXlXlX",
"lXkXnX4XP F H G H G H S A S S F v y.%X|..X X+XU.4.w.0.0.q.0.1.q.0.0.0.w.4.6.q.0.0.q.9.:.sXxXlXlX",
"lXkXMX=Xv.9X;X>X;X4X'.7.y.r.r.e.p.Q h z l l k Z 0.e.e.e.e.w.3.e.e.e.w.r.6.8.r.e.e.e.q.>.sXxXlXlX",
"lXkXMX*XC.tX5X8X5XdX+Xq.s.p.p.i.f.^ i j k j b D y.a.p.p.p.i.9.a.p.p.p.s.q.r.a.p.p.p.i.<.aXxXlXlX",
"lXkXMX*XN.eX9XwX9XhXXX0.p.i.i.u.d.~ a m m n Z D t.p.i.i.i.u.7.p.i.i.u.p.0.e.p.i.i.i.u.<.aXxXlXlX",
"lXkXMX*XB.eX7X0X8XgXoX0.a.i.i.u.d.~ p v b v B S t.p.i.i.i.u.8.p.i.i.i.a.0.e.p.i.i.i.u.<.aXxXlXlX",
"lXkXMX*XB.eX0XeXqXjXXX0.a.i.i.u.f.^ d N B N A D t.p.i.i.p.u.8.p.i.i.i.a.q.e.p.i.i.p.u.<.sXxXlXlX",
"lXkXMX&XN.kXaXdXsXlXOX9.p.u.u.y.d.R f M m m v N r.i.u.u.u.y.6.i.u.u.u.p.9.q.i.u.u.u.y.:.aXxXlXlX",
"lXkXnX3X6.x.j.j.j.l.i.:.<.<.<.<.1.X.) _ _ _ ) [ ,.<.<.<.<.<.;.<.<.<.<.<.:.>.<.<.<.<.:.4.fXzXlXlX",
"lXlXlXlXpXtXyXtXtXtXuXsXaXaXaXsXaXgXjXjXjXjXjXhXsXaXaXaXaXsXsXaXaXaXaXaXsXsXaXaXaXsXaXfXlXlXlXlX",
"lXlXlXlXxXcXcXcXcXcXcXxXxXxXxXxXxXzXzXzXzXzXzXzXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXzXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlX",
"lXlXlXzXnXnXnXnXnXnXmXmXmXmXmXmXmXmXmXmXmXmXMXMXMXMXMXmXnXnXnXnXnXnXMXMXMXMXNXnXlXlXlXlX",
"lXlXzXfX2X3X3X3X3X3X,X>X>X>X>X>X>X>X>X>X>X>X*X&X&X&X%X-X4X3X3X3X4X<X%X&X&X&X%X<XkXlXlXlX",
"lXkXnX2XG Z A A A C o.>.-.;.;.*.&.:.;.;.;.-.Z.J.G.F.I.i.N S A S M { I.F.G.G.J.w.tXcXkXlX",
"lXkXnX3XZ x v c v z 3.j.s.d.f.y.t.f.s.d.d.a.0XfXaXiXcX^.f b c n s &.gXqXrXwXzXZ.0XvXkXlX",
"lXkXnX3XA v n n n v <.s.u.u.p.w.q.p.u.i.u.y.,XwX9X7XiXY.j m n M g $.qX6X0X9XgXm.qXvXkXlX",
"lXkXnX3XA c n b b c 1.s.u.i.p.e.w.p.i.i.i.u.<XeX0X9XaXT.h m b m f $.eX6X0X9XgXM.qXvXkXlX",
"lXkXnX3XA b m n m v 1.d.u.i.p.e.e.s.p.a.a.i.1XrXqX9XsXR.g n b m f %.uXrXuXuXzXN.qXvXkXlX",
"lXkXnX4XB h l k l h <.d.u.i.p.e.5.q.0.q.0.q.,XwX9X8XpXT.k N m N j @.0X5X7X6XqXv.wXvXkXlX",
"lXkXMX-Xf.].!.~.~.~.~ S H G G H T.XX{.{.oXP.Y T T Y R Y N m m N k O.:X@X#X@X-Xl.wXvXkXlX",
"lXkXMX%XI.sXqXwXuXsXT g c c z v *XfXyXyXgX+Xf u d p k M l d j k g %.fXeXtXeXsXB.qXvXkXlX",
"lXkXMX&XF.wX9X9XtXeXR z m n b M +XtX8X8XyX Xl x N m A C l x m M v $.iX8X0X9XuXM.qXvXkXlX",
"lXkXMX&XG.wX8X8XrXrXR l m n b m @XtX9X9XyX Xk k b c V C l l b n c $.iX8X0X9XuXM.qXvXkXlX",
"lXkXMX&XJ.sXiXiXfXiXT k n b c n %XaXeXeXsXoXk b V N A B z n B C v $.fXeXrXeXsXB.qXvXkXlX",
"lXkXMX*XB.8X<X1X2X;XR x M m n N ].3X:X:X4X/.n C Z Z V V N V V Z z +.5X;X>X;X3Xc.wXvXkXlX",
"lXkXMX*XN.2X&X*X-XOX(.%X@X@X%X].K B V V V D B v v b l ~ $X+X+XoX:Xh.b D A S B ) dXxXkXlX",
"lXkXMX&XK.hXeXrXuX5X-XaXtXtXaX3XB i j f x B x d k k l ) iXyXyXrXlXN.p b c v h ! fXxXkXlX",
"lXkXMX&XG.aX8X0XeX1X#XeX9X9XeX:XV j N n Z Z x z M m m ( qX0X0X7XsXn.f M n m z ~ fXxXkXlX",
"lXkXMX&XG.pX8X9XwX<X#XrX9X9XeX:XV g n c B Z x k n b n ) qX0X0X7XsXn.d M b m l ~ fXxXkXlX",
"lXkXMX%XP.lXtXuXaX8X-XaXtXtXaX3XB z V N C N l c N N b ^ iXyXyXeXlXN.p n c v j ! fXxXkXlX",
"lXkXMX=Xz.$X|. XXX_.~.$XOXOX$X'.J A F D S D J K L P D ' @X+X+XoX;Xg.v S Z S N ) dXxXkXlX",
"lXkXnX3XZ x v v v x ;.t.q.q.e.7.9.y.r.t.t.r.*X4X1X<X8X~.4.e.q.q.w.4.r.t.t.t.t.<.uXcXkXlX",
"lXkXnX3XA c n b b c 2.f.p.p.s.r.w.a.p.p.p.i.3XyXeXwXaX].q.s.p.p.a.0.u.p.p.p.p.1.uXcXkXlX",
"lXkXnX3XA v n b n c 1.d.u.i.p.e.q.p.u.i.i.y.<XeX0X9XuX`.0.a.i.i.p.9.y.i.i.i.i.1.uXcXkXlX",
"lXkXnX3XA v n b b c <.s.y.u.i.w.w.a.i.i.i.u.,XwX9X8XyX`.0.a.i.u.p.9.y.i.i.i.i.1.uXcXkXlX",
"lXkXnX3XZ c b v b x 4.j.s.d.f.y.0.u.y.y.y.y.7XaXuXyXhX}.q.s.p.p.a.0.i.a.p.p.a.2.uXcXkXlX",
"lXkXnX3XD M B N N M O.1.>.,.,.=.t.h.f.f.g.p.!.[.`.`.}.A.4.q.0.0.0.2.9.0.0.0.9.>.iXcXkXlX",
"lXkXnX3XA b m n n M m g g g h b OXrX7X7XrXXX4.q.0.0.q.4.e.y.t.t.y.6.r.t.t.t.t.<.uXcXkXlX",
"lXkXnX3XZ c b b v m m f c z m C @XuXqXqXuX@Xe.s.a.a.s.q.y.p.p.p.a.9.u.p.p.p.p.1.uXcXkXlX",
"lXkXnX3XA c n b b m m j m b B V +XyX0X0XyX+Xq.p.i.i.p.0.t.p.i.i.p.9.u.i.i.i.i.1.uXcXkXlX",
"lXkXnX3XS n M m m N M h m b V C oXrX7X7XeXoXq.p.i.u.p.0.t.p.i.i.p.9.y.i.i.i.i.1.uXcXkXlX",
"lXkXnX4XM s g f f j c z N M N b :XlXsXsXlX;Xw.a.p.p.a.0.y.a.p.p.a.0.i.p.p.p.p.1.uXcXkXlX",
"lXkXnX<X{ &.$.$.$.#.~ W Q Q W W g.B.m.m.N.g.4.0.9.9.0.2.6.9.9.9.0.1.8.9.9.9.8.:.iXcXkXlX",
"lXkXMX%XI.gXqXeXyXrXh.s.f.d.g.u.z w t t t b r.u.y.y.i.9.r.u.u.y.i.8.t.u.u.u.u.1.uXcXkXlX",
"lXkXMX&XF.qX6X6XeX9Xp.y.u.u.i.e.B j m v V G t.p.i.i.a.0.t.p.i.i.p.9.u.p.i.i.p.1.uXcXkXlX",
"lXkXMX&XG.rX0X0XyXqXp.u.i.i.p.r.M j m b B D r.p.i.i.p.0.t.p.i.i.p.9.u.i.i.i.i.1.uXcXkXlX",
"lXkXMX&XG.wX9X9XyX0Xp.u.i.i.p.r.N k N n C F r.p.i.i.p.0.t.p.i.i.p.9.u.i.i.i.i.2.uXcXkXlX",
"lXkXNX%XJ.zXgXgXlXtXa.u.p.i.a.e.b x N M n B t.p.i.i.a.9.t.p.i.i.p.8.u.p.i.i.p.<.uXcXkXlX",
"lXkXnX<Xw.Z.m.M.M.n.2.1.1.1.2.,.( ! ~ ~ Q ( <.1.1.1.2.>.<.1.1.1.1.:.1.1.1.2.<.1.aXxXkXlX",
"lXlXlXkXtX0XqXqXqXwXuXuXuXuXuXuXdXfXfXfXfXdXuXuXuXuXuXiXuXuXuXuXuXiXuXuXuXuXuXaXlXlXlXlX",
"lXlXlXlXcXvXvXvXvXvXcXcXcXcXcXcXxXxXxXxXxXxXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXxXlXlXlXlX",
"lXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXcXcXcXcXcXvXvXvXvXvXvXvXvXvXbXbXbXnXvXxXcXcXcXbXbXbXnXvXlXlX",
"lXkXpXpXpXpXiXrXeXeXeXrXeXeXeXrX8X7X8X7XeXaXpXpXpX9X7X8X7XwXlXlX",
"cXpX` K U P W 4.6.5.5.1.5.5.5.4.H.E.U.^.8.F Y I I B.E.I.E.x.wXvX",
"cXpXK g x j V u.a.p.p.q.a.p.a.u.3XdXtXcXg.y v z l XXpX0XjX!.6XnX",
"cXpXY c N b D t.i.u.u.0.i.i.i.y.=XqX5XaXs.f N n n ].wX6XsXR.7XbX",
"cXpXL g x j V p.s.s.s.q.u.u.u.t.2XsXrXxXh.a m v v  XsXrXlXQ.7XnX",
"cXiX^ H I K T 4.6.6.5.7.s.a.s.u.(.OX|.&X9.k V M n /.6X>X6XH.8XbX",
"bX8XP.7X:X7X[.v b M d p.tX<X7X@XM g k z N x z x b `.7X>X8XL.8XbX",
"bX8XY.rX8XsX@Xc b M s f.hX9XuX:Xn k v B N h c b M XXaX0XsXR.7XbX",
"bX8XU.eX8XaX+Xn M V g d.pX5XwX*Xm z n V B z M N C }.tX5XtXU.8XbX",
"bX8XU.pXeXgXXXa s h 8 f.MXiXkX5XB M C A v a l l h $XzXpXxX~.7XnX",
"bX9XD.>X$X;X_.u.f.d.f.7.4.4.6.<.Z m N x ] l.s.g.p.3.6.6.6.>.rXvX",
"bX7XT.pX0XrX>XeXhXaXMX4.1 p u l x h z s q.nXpXhXyXA u g u G aXxX",
"bX8XY.uX8XeX-X,X0X5XpX5.p V B D x c M z 6.iX5X9X1XI v B v Y pXcX",
"bX7XE.dXeXiX<X5XuXqXjX5.y N M C l c M k 7.hXqXyX8XK l n l I pXcX",
"bX9XF.1X*X:X X#X,X=X7X2.x F A Z Z D H n 4.6X=X>X%XI n V b T iXcX",
"cXiXR M Z B H r.y.y.y.7.q.q.q.9. X:X&X,XS.0.u.u.e.7.w.q.w.1.rXvX",
"cXpXP k b z Z y.p.i.i.q.a.a.a.u.<XpXeXdXU.q.a.p.t.r.s.p.s.6.eXvX",
"cXpXU z m c S t.u.u.y.q.p.p.p.y.-XwX6XtXL.w.p.p.t.w.p.u.p.5.eXvX",
"cXpXI z n c S s.g.f.g.0.w.e.e.q.2XsXtXhXT.q.a.p.t.e.p.i.a.5.eXvX",
"cXpXY b B m A | |  .' 9.H.Z.D.M.D.U.L.T.g.7.q.q.8.6.w.0.q.1.rXvX",
"cXpXI z n b M h a g t g.zXeXaX1X0.q.w.q.7.i.i.i.r.w.p.u.p.5.eXvX",
"cXpXI z n v N x v N z f.sX6XeX-Xu.a.p.a.q.i.i.p.r.w.p.i.p.5.eXvX",
"cXpXI z n v M z v N l f.gX9XyX>Xu.p.p.p.q.i.p.a.t.e.a.i.a.6.eXvX",
"cXpXI l n v m m B A k p.uX2X9X%Xe.t.t.t.8.r.r.t.q.9.y.r.t.3.rXvX",
"bX9XB.XX]..XE.2.6.4.8.] S G F I 7.r.w.e.6.w.w.e.9.8.r.w.e.2.rXvX",
"bX7XE.pXwXfX>Xt.d.a.k.( y k k B w.s.p.p.w.p.p.a.y.r.a.p.a.6.eXvX",
"bX8XI.0X5XyX%Xq.i.y.f.) g N M D 0.p.u.i.0.u.i.i.r.w.p.u.p.5.rXvX",
"nX7XE.jXsXxX,Xe.a.i.h.^ d M n B q.s.p.a.q.p.p.a.t.e.a.p.s.5.eXvX",
"vXwXx.!.R.!.A.2.6.5.8.{ P T Y T 1.6.5.5.1.5.5.6.3.2.6.5.5.1.yXcX",
"lXlXwX6X7X7X9XrXeXeXeXyXpXiXiXiXrXeXeXeXrXeXeXeXrXrXeXrXeXyXkXlX",
"lXlXvXnXbXnXbXvXvXvXvXcXcXcXcXcXvXvXvXvXvXvXvXvXvXvXvXvXvXcXlXlX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"hX7X6X7X6X3X3X3X3X3X3X3X<X<X,X3X7X6X6X1X1X,X4XkX",
"7XU A A E q.9.8.5.0.9.0._.}.#Xq.m G S K.|.}.K.qX",
"6XS x z L s.i.i.r.s.p.d.6XtXkXd.i b z  XiXfX X7X",
"7XV g f H h.s.s.w.t.r.i.9XpXcXh.s M v {.iXdX}.8X",
"5X] _ _ [ >.>.-.e.v.z.k.I.E.).<.l N b /.6X5X!.9X",
"<X|.rXsX~.d n p B.sXeX#Xg p g b z z v [.qX0X).9X",
"1X'.wXsX^.l C j V.pXqX#Xv v V B x M B |.yXtX`.9X",
"<X].yXfXE.r k 0 Z.vXfX:Xm N A v d l h +XjXhX|.8X",
"<X^.2X<X_.n.C.Z.4.+.&.+.N m l o.H.V.M.;.&.%.:.yX",
"<X}.uXwX<XuXaXvX@.6 f x z c d u.vXaXuXH p p L aX",
"<XXXdXuX1X7XqXdX%.d V C k b g q.fXqX8XY x z R pX",
"1XR.=X$X{.%X=X3X&.m H D G I Z 0.4X=X%XE N M ! pX",
"6XG n b I i.t.t.0.t.e.y.*X2X6XH.0.u.e.0.t.r.q.tX",
"6XS x z L p.u.y.e.s.a.d.3XeXiXU.w.a.y.r.a.p.r.rX",
"6XD c x I j.g.g.0.w.q.t.7XuXfXT.q.a.y.e.p.i.e.rX",
"6XG n n F | } _ i.I.H.Z.H.U.R.j.9.e.0.8.e.w.9.tX",
"6XD c n m d h u Z.kXiX,X0.w.q.9.i.i.t.e.p.i.e.rX",
"6XD x b m x N z C.sXwX-Xu.a.a.e.i.p.y.r.a.p.r.rX",
"6XS z v n n C k N.iX9X%Xe.y.y.0.t.y.e.q.y.t.q.rX",
"1XK.|. XL.<.5.7._ G K E 0.r.e.8.e.r.q.9.r.e.0.tX",
"1X|.uXdX@Xr.s.k.T p l Z t.a.p.e.p.a.y.r.a.p.r.rX",
",X}.dXjX+X0.i.f.Y g b Z e.p.i.w.i.p.t.e.p.i.w.rX",
"4XK.|. XK.9.e.y.} T Q ~ 0.r.e.9.e.r.q.0.r.w.r.yX",
"kXqX7X8X0XtXrXrXiXpXpXpXtXrXrXtXrXrXrXtXrXrXyXlX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"kXiXuXyXrXtXtXtXwXwXyXiXtXwXrXkX",
"iX[ G &.s.r.p.s.}.-X&.M w.,X'.rX",
"uXC 4 { c.t.9.r.eXNXO.8 8.cX-XqX",
"tXf.l.>.~ ;.!.L.7.0.R s 7.rX}.wX",
"wX-XSXq.- { VX0Xl d k q q.NX;XwX",
"wX}.eXl.) 1.R.A.D N _ ..q.!.F.rX",
"wX&XrX3XvXR.8 z x s W.SXj.5 H uX",
"wX|.1X+X9XH.b G D B G.pXd.h Q uX",
"uXQ v +.h.e.w.t.@X1Xb.u.r.q.r.tX",
"uXP a X.l.r.w.y.6XdXM.w.t.i.p.tX",
"uXT v K H #..X/.n.m.u.r.q.e.t.tX",
"uXS u j e X.VXtXu.w.r.p.t.i.p.tX",
"tX0.9.$.) #.j.d.r.t.q.t.q.e.y.tX",
"wX:XBXW.s.-.6 j q.i.e.i.e.u.u.rX",
"rX`.,XC.y.2.I ~ r.p.t.p.y.u.a.yX",
"kXrXqXrXtXtXuXyXtXtXtXtXtXrXyXkX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
